pub struct Coordinate {
pub lat: f64,
pub lng: f64,
}Expand description
A geographical coordinate expressed as latitude and longitude in decimal degrees.
The coordinate uses a conventional Earth-based reference system, where:
- Latitude ranges from -90.0° (south pole) to +90.0° (north pole).
- Longitude ranges from -180.0° (west) to +180.0° (east).
Fields
lat- The latitude in decimal degrees, where positive values represent the northern hemisphere.lng- The longitude in decimal degrees, where positive values represent the eastern hemisphere.
Fields
lat: f64lng: f64Trait Implementations
Sourceimpl Clone for Coordinate
impl Clone for Coordinate
Sourcefn clone(&self) -> Coordinate
fn clone(&self) -> Coordinate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Coordinate
impl Debug for Coordinate
Sourceimpl PartialEq for Coordinate
impl PartialEq for Coordinate
impl Copy for Coordinate
impl Eq for Coordinate